@@ -1,115 +1,119 @@
 #[derive(Debug, Clone, PartialEq)]
 pub struct Forms {
-    pub list: Vec<Form>,
+    pub desk: Vec<Form>,
 }
 
 #[derive(Debug, Clone, PartialEq)]
 pub struct Form {
-    pub part: String,
+    pub term: String,
 }
 
 impl Forms {
-    pub fn new(list: Vec<Form>) -> Forms {
-        Forms { list }
+    pub fn edit() -> Forms {
+        Forms { desk: Vec::new() }
+    }
+
+    pub fn new(desk: Vec<Form>) -> Forms {
+        Forms { desk }
     }
 
     pub fn from(slice: &[impl AsRef<str>]) -> Forms {
-        let mut list: Vec<Form> = Vec::with_capacity(slice.len());
+        let mut desk: Vec<Form> = Vec::with_capacity(slice.len());
         for item in slice {
-            list.push(Form::new(item.as_ref()));
+            desk.push(Form::new(item.as_ref()));
         }
-        Forms { list }
+        Forms { desk }
     }
 
     pub fn len(&self) -> usize {
-        self.list.len()
+        self.desk.len()
     }
 
     pub fn get(&self, index: usize) -> &Form {
-        &self.list[index]
+        &self.desk[index]
     }
 
     pub fn set(&mut self, index: usize, form: Form) {
-        self.list[index] = form;
+        self.desk[index] = form;
     }
 
     pub fn add(&mut self, index: usize, form: Form) {
-        self.list.insert(index, form)
+        self.desk.insert(index, form)
     }
 
     pub fn put(&mut self, form: Form) {
-        self.list.push(form)
+        self.desk.push(form)
     }
 
     pub fn del(&mut self, index: usize) -> Form {
-        self.list.remove(index)
+        self.desk.remove(index)
     }
 
     pub fn pop(&mut self) -> Option<Form> {
-        self.list.pop()
+        self.desk.pop()
     }
 
     pub fn change_all(&mut self, of: &str, to: &str) {
-        for form in &mut self.list {
-            if form.part == of {
-                form.part = to.into();
+        for form in &mut self.desk {
+            if form.term == of {
+                form.term = to.into();
             }
         }
     }
 
     pub fn build(&self) -> String {
         let mut result = String::new();
-        for form in &self.list {
-            result.push_str(&form.part);
+        for form in &self.desk {
+            result.push_str(&form.term);
         }
         result
     }
 }
 
 impl Form {
-    pub fn new(part: &str) -> Form {
-        Form { part: part.into() }
+    pub fn new(term: &str) -> Form {
+        Form { term: term.into() }
     }
 
-    pub fn from(part: String) -> Form {
-        Form { part }
+    pub fn from(term: String) -> Form {
+        Form { term }
     }
 
     pub fn is_whitespace(&self) -> bool {
-        !self.part.chars().any(|ch| !ch.is_whitespace())
+        !self.term.chars().any(|ch| !ch.is_whitespace())
     }
 
     pub fn is_linespace(&self) -> bool {
         !self
-            .part
+            .term
             .chars()
             .any(|ch| LINE_SPACE_CHARS.iter().any(|item| ch != *item))
     }
 
     pub fn is_linebreak(&self) -> bool {
         !self
-            .part
+            .term
             .chars()
             .any(|ch| LINE_BREAK_CHARS.iter().any(|item| ch != *item))
     }
 
     pub fn is_code_brackets(&self) -> bool {
         !self
-            .part
+            .term
             .chars()
             .any(|ch| CODE_BRACKETS_CHARS.iter().any(|item| ch != *item))
     }
 
     pub fn is_text_brackets(&self) -> bool {
         !self
-            .part
+            .term
             .chars()
             .any(|ch| TEXT_BRACKETS_CHARS.iter().any(|item| ch != *item))
     }
 
     pub fn is_text_quotation(&self) -> bool {
         !self
-            .part
+            .term
             .chars()
             .any(|ch| TEXT_QUOTATION_CHARS.iter().any(|item| ch != *item))
     }
